Entity: Entity

EntityR Documentation

Entity

Description

R6 simulation state container used by fluxCore::Engine. An Entity stores current state, event history, derived-variable registrations, and metadata such as id and optional meta$entity_type.

Methods

Public methods


Entity$new()

Usage
Entity$new(
  init = list(),
  schema,
  derived_vars = NULL,
  id = NULL,
  entity_type = NULL,
  time0 = 0,
  event_type0 = "init"
)

Entity$state()

Usage
Entity$state(vars = NULL)

Entity$as_list()

Usage
Entity$as_list(vars = NULL)

Entity$update()

Usage
Entity$update(time, event_type, changes = NULL)

Entity$state_at_time()

Usage
Entity$state_at_time(time, vars = NULL)

Entity$snapshot()

Usage
Entity$snapshot(vars = NULL)

Entity$snapshot_at()

Usage
Entity$snapshot_at(j, vars = NULL)

Entity$snapshot_at_time()

Usage
Entity$snapshot_at_time(time, vars = NULL)

Entity$state_at()

Usage
Entity$state_at(j, vars = NULL)

Entity$clone()

The objects of this class are cloneable with this method.

Usage
Entity$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


fluxCore documentation built on Sept. 22, 2026, 5:07 p.m.