MLflowProvider: MLflowProvider (internal stub)

MLflowProviderR Documentation

MLflowProvider (internal stub)

Description

Scaffold for MLflow-based workflows. model_spec should include at least model_uri and optionally references to artifacts needed to build a bundle.

Details

Deprecated in v2.0.0. Use load_model() or Engine$new(bundle = ...) instead.

Methods

Public methods


MLflowProvider$new()

Usage
MLflowProvider$new(builder_fn, sampler_fn = NULL)
Arguments
builder_fn

Function returning a ModelBundle.

sampler_fn

Optional function returning a list of length D parameter contexts.


MLflowProvider$load()

Usage
MLflowProvider$load(model_spec, ...)

MLflowProvider$sample_param_draws()

Usage
MLflowProvider$sample_param_draws(model_spec, n_param_draws = 1L, ...)

MLflowProvider$clone()

The objects of this class are cloneable with this method.

Usage
MLflowProvider$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


fluxCore documentation built on Sept. 22, 2026, 5:07 p.m.