schema_blocks: List unique schema blocks

View source: R/schema.R

schema_blocksR Documentation

List unique schema blocks

Description

Extract the set of unique block names declared in a schema via the optional blocks metadata field on each variable entry. Variables may belong to multiple blocks (many-to-many).

Usage

schema_blocks(schema)

Arguments

schema

An entity state schema (named list).

Value

Character vector of unique block names.


fluxCore documentation built on Sept. 22, 2026, 5:07 p.m.