schema_validate: Validate an entity schema

View source: R/schema_helpers.R

schema_validateR Documentation

Validate an entity schema

Description

Validates the structure and required metadata of an entity schema. The schema is a named list where each entry describes one state variable.

Usage

schema_validate(schema)

Arguments

schema

A named list schema.

Value

The validated schema (invisibly), with normalized type fields.


fluxCore documentation built on Sept. 22, 2026, 5:07 p.m.