View source: R/vector_helpers.R
| set_vars_from_named | R Documentation |
Convert a named vector into a named list suitable for returning from transition(). Optionally select and order a subset via vars.
set_vars_from_named(x, vars = NULL)
x |
Named vector (e.g., numeric) of updates. |
vars |
Optional character vector specifying which names to take and in what order.
If provided, values are taken as |
Named list suitable for transition() returns.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.