| Entity | R Documentation |
R6 simulation state container used by fluxCore::Engine. An Entity stores current state, event history, derived-variable registrations, and metadata such as id and optional meta$entity_type.
Entity$new()Entity$new( init = list(), schema, derived_vars = NULL, id = NULL, entity_type = NULL, time0 = 0, event_type0 = "init" )
Entity$state()Entity$state(vars = NULL)
Entity$as_list()Entity$as_list(vars = NULL)
Entity$update()Entity$update(time, event_type, changes = NULL)
Entity$state_at_time()Entity$state_at_time(time, vars = NULL)
Entity$snapshot()Entity$snapshot(vars = NULL)
Entity$snapshot_at()Entity$snapshot_at(j, vars = NULL)
Entity$snapshot_at_time()Entity$snapshot_at_time(time, vars = NULL)
Entity$state_at()Entity$state_at(j, vars = NULL)
Entity$clone()The objects of this class are cloneable with this method.
Entity$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.