| MLflowProvider | R Documentation |
Scaffold for MLflow-based workflows. model_spec should include at least model_uri and optionally references to artifacts needed to build a bundle.
Deprecated in v2.0.0. Use load_model() or Engine$new(bundle = ...) instead.
MLflowProvider$new()MLflowProvider$new(builder_fn, sampler_fn = NULL)
builder_fnFunction returning a ModelBundle.
sampler_fnOptional function returning a list of length D parameter contexts.
MLflowProvider$load()MLflowProvider$load(model_spec, ...)
MLflowProvider$sample_param_draws()MLflowProvider$sample_param_draws(model_spec, n_param_draws = 1L, ...)
MLflowProvider$clone()The objects of this class are cloneable with this method.
MLflowProvider$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.