| schema_blocks | R Documentation |
Extract the set of unique block names declared in a schema via the optional blocks metadata field on each variable entry. Variables may belong to multiple blocks (many-to-many).
schema_blocks(schema)
schema |
An entity state schema (named list). |
Character vector of unique block names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.