View source: R/schema_helpers.R
| schema_validate | R Documentation |
Validates the structure and required metadata of an entity schema. The schema is a named list where each entry describes one state variable.
schema_validate(schema)
schema |
A named list schema. |
The validated schema (invisibly), with normalized type fields.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.